import test_path
from pyspeedx.text import * 


if __name__ == "__main__":
    # ## test Word class ##
    # _str = "hello"
    # word = Word(_str)
    # print("word: \n", word)
    # #####################


    # ## test Text class ##
    # _str = "hello Text this is a long text"
    # print("text to words: \n",Text.text_to_str_list(_str))
    # Text.palindromic_partitions(_str)
    # #####################

    # ## test Sound class ##
    
    # # make a long text made of words
    # # convert text to list of strings 
    # # from the list of strings create a list of sounds
    # #   
    # sound = Sound("sound")
    # print("sound:\n", sound)

    # str_list = Text.text_to_str_list("time to hear the sounds of these words")
    # sounds_list = list(map(Sound,str_list)) 
    
    # print(*sounds_list,sep='\n')
    
    # ######################

    # ## test similarity_weight() ##
    # from sort import Sort

    # sound1 = Sound('cat hat')
    # sound2 = Sound('fat rat')
    # print("sound1:\n",sound1)
    # print("sound2:\n",sound2)

    # weight = similarity_weight(sound1,sound2)
    # _weight_len_product = weight_len_product(weight)
    # sort_weight_len_product = Sort.sort_dict_by_value(_weight_len_product)

    # print("weight:\n",weight)
    # print("sorted weight:\n",Sort.sort_dict_by_value(weight))
    # print("sorted weight_len_product:\n",sort_weight_len_product)

    # ######################

    # ## Test hashable sound ##
    # import pprint
    # sound1 = Sound('drink')
    # _dict = {}
    # _dict[sound1] = 5
    # _dict[Sound('mat')] = 3
    
    # #print("_dict:\n",_dict)
    # pprint.pprint(_dict)
    
    # ##########################

    ## Test save data to csv ##
    import pandas as pd
    
    data = {'col_1': [3, 2, 1, 0], 'col_2': ['a', 'b', 'c', 'd']}
    # data = {'a':1,'b':2,'c':3}
    # pd.DataFrame(d.items(), columns=['Date', 'DateValue'])
    data_frame = pd.DataFrame(data.items(), columns=['key', 'value'])
    print(data_frame)
    # exit()
    
    sound1 = Sound('drink')
    sound2 = Sound('good')
    
    _dict = {}
    _dict[sound1] = 5
    _dict[Sound('mat')] = 342
    
    #_dict2 = {sound2:1,'b':2,'c':sound1}
    # data_frame = pd.DataFrame(_dict2)
    #data_frame = pd.DataFrame(_dict2.items(),columns=['word','count'])

    data_frame = pd.DataFrame(_dict.items(),columns=['sound','count'])
    # print("type(data_frame['word'][0]:",type(data_frame['word'][0]))
    
    print(data_frame)
    Helper.save_data_frame_to_csv("sound_count_data.csv",data_frame)



# content of test_sample.py
# from pyspeedx import pyspeedx
import test_path
import os 

import pyspeedx.helpers
dir_path = os.path.dirname(os.path.realpath(__file__))
print(dir_path)



def func(x):
    return x + 1


def test_answer():
    assert func(3) == 4


import pyspeedx.pyspeedx.logger.Logger 

logger = L.Logger.getInstance()
class Pronunciation:
  #sound = None; 
  def __init__(self,sound):
    self.sound = sound;

  def __str__(self):
    return str(self.sound)
  def __eq__(self,other):
    return self.sound == other.sound
  def __hash__(self):
    _hash = tuple(self.sound)
    #logger.log("_hash: %s" %str(_hash))
    return hash(str(self.sound))
    
    #return hash(tuple(self.sound))


if __name__ == "__main__":
        
    hs = Pronunciation(g2p("home"))
    hs2 = Pronunciation(g2p("room")) 
    logger.log("1)hs: %s" % hs)
    logger.log("1_2)hs2: %s" % hs2)

    _dict = {}
    _dict[hs] = 53
    _dict[hs2] = 25
    logger.log("2)_dict: %s" % _dict)

    logger.log("3)_dict[hs]: %s" % _dict[hs])
    logger.log("4)_dict[hs2]: %s" % _dict[hs2])


    #logger.log("3)_dict[hs.sound]: %s" % _dict[hs.sound])




import sys
import os
# print("sys.path: ",sys.path)
# sys.path.append("E:\\tools\\python\\pyspeedx\\")
# sys.path.append("..\\pyspeedx\\")

path = os.path.abspath(__file__)
_dir = os.path.dirname(path)
package_dir = os.path.join(_dir,'..')
print("Test dir is : ",_dir)
print("package_dir  is : ",package_dir)

sys.path.append(package_dir)

# pyspeedx_path = os.path.dirname(path,'..')


# print(os.path.realpath(__file__))

# print("__file__ is :",__file__)
# print("__package__ is :",__package__)

# import os
# print (__file__)
# print (os.path.abspath(__file__))

#print("pyspeedx path is : ",pyspeedx_path)


# sys.path.append(os.path.join(os.path.dirname(sys.path[0]),'..'))


#importing module 
import logging 
  
class Logger:
    __instance = None # singleton
    __logger = None #use log() to access it 

    @staticmethod
    def getInstance():
        if Logger.__instance == None: # do only once
            Logger() # call class __init__ method
        
        #print("point_3 check: %s" % Logger.__instance)
        return Logger.__instance
    
    
    def __init__(self,file_path="newfile.log"):
        if Logger.__instance == None:
            #print("point_1 , check,Logger.__instance : {}".format(Logger.__instance))
            #print(file_path)
            #Create and configure logger 
            logging.basicConfig(filename=file_path, 
                            format='%(asctime)s %(message)s', 
                            filemode='w') 
            #Creating an object 
            self.__logger = logging.getLogger() 
            #print("point_2 , check, self.__logger {}".format(self.__logger))
            # if (self.logger.hasHandlers()):
            #     self.logger.handlers.clear()
        
            console = logging.StreamHandler()
            self.__logger.addHandler(console)



            
            #Setting the threshold of logger to DEBUG 
            self.__logger.setLevel(logging.DEBUG) 
            Logger.__instance = self
        else:
            print("*****************A singleton already exist******************")
            #print("Logger.__instance: {}".format(Logger.__instance))
            #return Logger.__instance
            raise RuntimeError('A singleton already exist')
    
    def log(cls,message): 
        cls.__logger.info(message)

    #turn logger on(True) or off(False)  
    
    def on(cls,state: bool):
        if(state == False): #off
            cls.__logger.disabled = True #disable logger
        else:# state == True
            cls.__logger.disabled = False # enable logger

    #_list: list of str , convet with list(map(str,_list)) if _list[i] is not str
    def log_list(_list: list, limit):
        # for i in _list:
        #   _str = i
        _str = ", ".join(_list[:limit])
        logger.log(_str)

    def log_dict(cls,_dict:dict, limit):
        counter = 0 
        
        for k,v in _dict.items() :
            cls.log("rank:  {}  ,   {}   , score:  {}".format(counter,k,v))
            if counter > limit:
                break
            counter +=1
        
    # def print_dict(dic,limit):
    #     counter = 0 
    #     for w in dic:
    #         print("rank: " + str(counter) + ", " + w + ", score: "+ str(dic[w]))
    #         if counter > limit:
    #             break
    #         counter +=1
    
    def print_dict(cls,_dict:dict,limit):
        counter = 0 
        
        for k,v in _dict.items() :     
            print("index:  {}  , key:  {}   , value:  {}".format(counter,k,v))
            if counter > limit:
                break
            counter +=1

if __name__ == "__main__":
    #logger = Logger()

    logger = Logger.getInstance()
    #exit()
    #logger = Logger()
    #print(logger)
    _list = "this is a list of string".split(" ")
    _dict = {k:len(k) for k in _list }

    #logger.on(False)
    logger.log("hey there!")
    logger = Logger.getInstance()
    logger = Logger.getInstance()

    #logger = Logger()
    #logger = Logger()
    #logger = Logger()

    logger.log("_list1: %s" % _list)
    #exit()
    

    logger.log("_dict1: %s" % _dict)

    logger.on(False)
    #wont log
    logger.log("_list2: %s" % _list)
    logger.log("_dict2: %s" % _dict)

    logger.on(True)
    #will log 
    logger.log("_list3: %s" % _list)
    logger.log("_dict3: %s" % _dict)



from test import Test
from helpers import Helper

if __name__ == "__main__":


    Test.print_hello()
    l_str  = "abcd"
    _str = "qwert asdf zxcb"
    _str_list = _str.split(" ")
    print("_str_list: ",_str_list)
    print("_str_list type: ",type(_str_list))
    list2d = list(map(list,_str_list))

    print("type of list2d: ",type(list2d))
    print("list2d: ",list2d)
    
    #l = list(l_str)
    #perms = Helper.permutations(l_str)
    #print("permutation of %s: " % l_str)
    #print(perms)
    
    flat_perms = Helper.permutations_on_2dlist(list2d)
    print("flat_perms: ",flat_perms)

    list_str = list(map("".join,flat_perms))
    print("list_str: ",list_str)
